@@ -33,24 +33,18 @@ class Storage(driver.Base):
 
     def content_redirect_url(self, path):
         logger.info("content_redirect_url path:%s" % path)
-        path = self._init_path(path)
-        object_instance = self._jss.bucket(self._bucket).object(path)
+        path1 = self._init_path(path)
+        object_instance = self._jss.bucket(self._bucket).object(path1)
         
         return object_instance.generate_url("GET")
     
-    def get_json(self, path):
-        try:
-            return json.loads(self.get_unicode(path))
-        except:
-            return []
-            
     @lru.get
     def get_content(self, path):
         logger.info("get_content path:%s" % path)
-        path = self._init_path(path)
+        path1 = self._init_path(path)
         output = StringIO.StringIO()
         try:
-            object_instance = self._jss.bucket(self._bucket).object(path)
+            object_instance = self._jss.bucket(self._bucket).object(path1)
             res = object_instance.download_flow()
             while True:
                 data = res.read(1024)
@@ -61,7 +55,7 @@ class Storage(driver.Base):
                     
             return output.getvalue()
         except Exception as e:
-            print e
+            logger.error("get_content error:%s" % e)
         finally:
             output.close()
 
@@ -69,35 +63,35 @@ class Storage(driver.Base):
     @lru.set
     def put_content(self, path, content):
         logger.info("put_content path:%s" % path)
-        path = self._init_path(path)
+        path1 = self._init_path(path)
         try:
-            object_instance = self._jss.bucket(self._bucket).object(path)
+            object_instance = self._jss.bucket(self._bucket).object(path1)
             object_instance.upload_flow(None, None, content)
         except Exception as e:
-            print e
+            logger.error("put_content error:%s" % e)
             raise e
         return path
 
     def stream_write(self, path, fp):
         logger.info("stream_write path:%s" % path)
-        path = self._init_path(path)
+        path1 = self._init_path(path)
         part_size = 5 * 1024 * 1024
         if self.buffer_size < part_size:
             part_size = self.buffer_size
         try:
-             object_instance = self._jss.bucket(self._bucket).object(path)
+             object_instance = self._jss.bucket(self._bucket).object(path1)
              object_instance.multi_upload_fp(None, None, fp, part_size)
         except Exception as e :
-            print e
+            logger.error("stream_write error:%s" % e)
             raise e
 
     @lru.remove
     def remove(self, path):
         logger.info("remove path:%s" % path)
-        path = self._init_path(path)
+        path1 = self._init_path(path)
 
         try:
-           self._jss.bucket(self._bucket).delete_key(path)
+           self._jss.bucket(self._bucket).delete_key(path1)
         except Exception as e:
-            print e
+            logger.error("remove error:%s" % e)
             raise e
